#
# spec file for package backintime
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           backintime
Version:        1.3.3
Release:        2.1
Summary:        Backup tool for Linux inspired by the "flyback project"
License:        GPL-2.0-or-later
URL:            https://github.com/bit-team/backintime
Source0:        https://github.com/bit-team/backintime/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/bit-team/backintime/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
# Public key mentioned in https://github.com/bit-team/backintime#archlinux
Source2:        %{name}.keyring
Source3:        %{name}.png
# PATCH-FEATURE-OPENSUSE %%{name}-polkit_priv_downgrade.patch boo#1007723
Patch0:         %{name}-polkit_priv_downgrade.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
Requires:       cron
Requires:       dbus-1-python3
Requires:       openssh
%if 0%{?suse_version} > 1500
Requires:       pkexec
%endif
Requires:       python3
Requires:       python3-keyring
Requires:       python3-packaging
Requires:       rsync
Recommends:     encfs
Recommends:     sshfs
Requires:       libnotify-tools
Conflicts:      backintime-gnome
Conflicts:      backintime-kde
Obsoletes:      backintime-doc < %{version}
Provides:       backintime-doc = %{version}-%{release}
BuildArch:      noarch

%description
Back In Time is a backup tool for Linux inspired by the "flyback project".

It provides a command line client 'backintime' and a Qt5 GUI 'backintime-qt'
both written in Python3.

You only need to specify 3 things:
    * where to save snapshots;
    * what folders to backup; and
    * backup frequency (manual, every hour, every day, every month).

%package qt
Summary:        Back In Time Qt5 GUI
Requires:       %{name} = %{version}
Requires:       dbus-1-python3
Requires:       polkit
Requires:       python3-qt5
Obsoletes:      backintime-qt4

%description qt
This package has a Qt5 GUI for %{name}.

%lang_package

%prep
%setup -q
%patch0

%build

# Fix documentation directories.
sed -i -e "s|'doc'|'doc/packages'|g" common/config.py
sed -i -e "s|'backintime-common'|'backintime'|g" common/config.py
sed -i -e "s|/share/doc/|/share/doc/packages/|g" common/configure qt/configure
sed -i -e "s|backintime-common|backintime|g" common/configure qt/configure

# Fix icon name.
sed -i 's/Icon=document-save/Icon=backintime/g' qt/backintime-qt.desktop qt/backintime-qt-root.desktop

# Fix shebangs
sed -i 's|/usr/bin/env python|#!/usr/bin/python|g' common/askpass.py

pushd common
./configure --python3
make %{?_smp_mflags}
popd
pushd  qt
./configure --python3
make %{?_smp_mflags}
popd

%install
pushd common
%make_install
popd
pushd qt
%make_install
popd

# Remove unmaintained documentation.
rm -r %{buildroot}%{_docdir}/qt

install -D -m 644 %{SOURCE3} %{buildroot}/%{_datadir}/pixmaps/%{name}.png

# Fix duplicated files.
%fdupes %{buildroot}%{_datadir}/icons/hicolor/

%suse_update_desktop_file %{name}-qt System Backup
%suse_update_desktop_file %{name}-qt-root System Backup

%find_lang %{name} --without-kde --without-gnome

%postun
rm -f %{_sysconfdir}/udev/rules.d/99-backintime-*.rules

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_bindir}/%{name}-askpass
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/actions/show-hidden.svg
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/bash-completion
%{_docdir}/%{name}/
%{_mandir}/man1/%{name}-askpass.1%{ext_man}
%{_mandir}/man1/%{name}-config.1%{ext_man}
%{_mandir}/man1/%{name}.1%{ext_man}
%{_sysconfdir}/xdg/autostart/backintime.desktop
%exclude %{_docdir}/%{name}-*/
%exclude %{_datadir}/%{name}/qt
%exclude %{_datadir}/%{name}/plugins

%files lang -f %{name}.lang

%files qt
%defattr(-,root,root)
%{_bindir}/%{name}-qt
%{_bindir}/%{name}-qt_polkit
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/applications/%{name}-qt-root.desktop
%{_datadir}/%{name}/qt
%{_datadir}/%{name}/plugins
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/system-services
%{_datadir}/dbus-1/system-services/net.launchpad.backintime.serviceHelper.service
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/net.launchpad.backintime.policy
%{_docdir}/%{name}-qt/
%{_mandir}/man1/%{name}-qt.1%{ext_man}
%dir %{_sysconfdir}/dbus-1
%dir %{_sysconfdir}/dbus-1/system.d
%config %{_sysconfdir}/dbus-1/system.d/net.launchpad.backintime.serviceHelper.conf

%changelog
* Sun Feb  5 2023 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Require python3-packaging
* Sun Jan  8 2023 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Remove backintime-rsync324_args.patch (no longer needed)
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.3:
  * New feature: Command line argument "--diagnostics" to show helpful info
    for better issue support
  * GUI change: Remove Exit button from the toolbar
  * GUI change: Define accelerator keys for menu bar and tabs, as well as
    toolbar shortcuts
  * Desktop integration: Update .desktop file to mark Back In Time as a
    single main window program
  * Improvement: Write all log output to stderr; do not pollute stdout with
    INFO and WARNING messages anymore
  * Bugfix: RTE "reentrant call inside io.BufferedWriter" in logFile.flush()
    during backup
  * Bugfix: Incompatibility with rsync 3.2.4 or later because of rsync's
    "new argument protection" (#1247). Deactivate "--old-args" rsync
    argument earlier recommaned to users as a workaround.
  * Bugfix: DeprecationWarnings about invalid escape sequences.
  * Bugfix: AttributeError in "Diff Options" dialog
  * Bugfix: Settings GUI: "Save password to Keyring" was disabled due to "no
    appropriate keyring found"
  * Bugfix: Back in Time did not start with D-Bus error
  * Bugfix: Avoid logging errors while waiting for a target drive to be
    mounted
  * Bugfix: [Arch Linux] AUR pkg "backintime-git": Build tests fails and
    installation is aborted
  * Bugfix: Wrong systray icon showing in Wayland
  * Documentation update: Correct description of profile<N>.schedule.time in
    backintime-config manpage
  * Translation update: Brazilian Portuguese
  * Translation update: Italian
  * Translation update: French
  * Testing: Fix a test fail when dealing with an empty crontab
  * Testing: Fix a test fail when dealing with an empty config file
  * Testing: Skip "test_quiet_mode" (does not work reliably)
  * Testing: Improve "test_diagnostics_arg" (introduced with #1100) to no
    longer fail when JSON output was mixed with logging output (part of #921)
  * Testing: Numerous fixes and extensions to testing
* Sat Nov 19 2022 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- add backintime-rsync324_args.patch for Tumbleweed
  + rsync 3.2.4 changes argument syntax; workaround until next release of backintime
- require notify-send (libnotify-tools) for error messages
* Sun Aug 14 2022 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Don't require pkexec on Leap.
* Mon Jul 18 2022 Marcus Meissner <meissner@suse.com>
- require pkexec as this is now a standalone package.
* Wed May 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.3.2:
  + Fix bug: Tests no longer work with Python 3.10.
* Wed Jul  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.3.1
  * Match old and new rsync version format
  * Keep permissions of an existing mountpoint from being overridden
  * Fix FileNotFoundError exception in mount.mounted
  * Fix: 'TempPasswordThread' object has no attribute 'isAlive'
  * Fix: YEAR missing in config
  * Fix: SSH module didn't send identification string while checking if remote host is avilable (#1030)
  * QT: Fix notifyplugin
  * QT: Fix theming: Use link Color instead of hardcoded lightGray
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Thu Aug 29 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to upstream version 1.2.1
  * Fix bug: TypeError in backintime.py if mount failed while running a snapshot
* Mon May 13 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary.
* Mon Apr 29 2019 Tim Hardeck <thardeck@suse.com>
- Update to upstream version 1.2.0
  * switch to Qt5
  * rewrite huge parts
  * add unit-test for most important parts
- remove obsolete patch backintime-ssh-agent_only_if_password.patch
- remove obsolete patch backintime-security_hardening_backport.patch
- add gpg verification for source tarball
- remove obsolete %%post and %%postun statements
* Sat Nov 18 2017 tejas.guruswamy@opensuse.org
- Update to upstream version 1.1.24
  * fix critical bug: shell injection in notify-send (https://github.com/bit-team/backintime/issues/834)
  * fix bug: stat free space for snapshot folder instead of backintime folder (https://github.com/bit-team/backintime/issues/733)
  * backport bug fix: backintime root crontab doesn't run; missinng line-feed 0x0A on last line (https://github.com/bit-team/backintime/issues/781)
  * backport bug fix: can't open files with spaces in name (https://github.com/bit-team/backintime/issues/552)
* Mon May 15 2017 tejas.guruswamy@opensuse.org
- Remove rpmlintrc following security review
* Thu Apr 20 2017 tejas.guruswamy@eopensuse.org
- Update to 1.1.20
  * backport security fix: polkit CheckAuthorization: race condition in privilege authorization (CVE-2017-7572, boo#1032717)
- Don't store passwords given to polkit helper
  * backintime-polkit_priv_downgrade.patch
- Backport security hardening measures (boo#1007723)
  * backintime-security_hardening_backport.patch
- Fix Requires and BuildRequires
  * No longer requires xterm
  * Note: backintime requires python3-keyring (not py2), but not available in openSUSE yet
- Delete udev configuration files on uninstall
- Merge doc subpackage into main package
* Sat Oct 29 2016 felibank@gmail.com
- Added a new script for launching backintime as root from desktop
  (boo#1006356)
* Tue Jan 12 2016 ronisbr@gmail.com
- Remove unnecessary patch that was already applied by upstream:
  * backintime-1.1.10-AttributeError-About-Dialog.patch
- Remove the workaround for x-terminal-emulator. Upstream developed
  a new dialog to avoid this problem.
- Version bump to 1.1.12.
  Upstream changelog:
  * Fix bug: remove x-terminal-emulator dependency (#515)
  * Fix bug: AttributeError in About Dialog (#515)
* Mon Jan 11 2016 ronisbr@gmail.com
- backintime-qt4 uses x-terminal-emulator to open a terminal with a
  man page in the menus Help->Help and Help->Config File Help.
  However, openSUSE does not have x-terminal-emulator, instead it
  has xdg-terminal that does not work because it can only accept
  one argument. Thus, the solution was to replace
  x-terminal-emulator with xterm. Now, everything in the Help menu
  is working properly.
* Mon Jan 11 2016 ronisbr@gmail.com
- Remove unnecessary BuildRoot in spec file.
- Change package URL to https://github.com/bit-team/backintime .
- Add patch backintime-1.1.10-AttributeError-About-Dialog.patch to
  fix upstream issue #515. For more information, see:
    https://github.com/bit-team/backintime/issues/515
- Fix doc path so that the buttons Authors, Translations, and
  License in About dialog work properly.
* Sun Jan 10 2016 ronisbr@gmail.com
- Remove the patch:
    backintime-AttributeError_if_keyring_is_missing.patch
  since the addressed issue was already solved by upstream.
- Change source URL to github.
- Run spec-cleaner.
- Version bump to 1.1.10.
  Upstream changelog:
  * Fix bug: failed to remove empty lock file (#505) Add Icon
    'show-hidden' (#507)
  * Add Modify for Full System Backup button to settings page, to
    change some profile settings
  * Fix bug: Restore the correct file owner and group fail if
    they are not present in system (#58)
  * add get|set_list_value to configfile
  * Fix bug: QObject::startTimer error on closing app
  * subclass ApplicationInstance in GUIApplicationInstance to
    reduce redundant code
  * speed up app start by adding snapshots to timeline in
    background thread
  * add warning on failed permission restore (#58)
  * add unittest (thanks to Dorian, Alexandre, Aurélien and
    Gregory from IAGL)
  * Fix bug: FileNotFoundError while starting pw-cache from
    source
  * continue an unfinished new_snapshot if possible (#400)
  * Fix bug: suppress warning about failed inhibit suspend if run
    as root (#500)
  * Fix bug: UI blocked/greyed out while removing snapshot (#487)
  * Fix bug: pw-cache failed on leftover PID file, using
    ApplicationInstance now (#468)
  * Fix bug: failed to parse some arguments (#492)
  * Fix bug: failed to start GUI if launched from systray icon
  * Fix bug: deleted snapshot is still listed in Timeline if
    using mode SSH (#493)
  * Fix bug: PermissionError while deleting readonly files on
    sshfs mounted share (#490)
  * Add Nautilus-like shortcuts for navigating in file browser
    (#483)
  * speed up mounting of SSH+encrypted profiles
  * Fix bug: creat new encrypted profiles with encfs >= 1.8.0
    failed (#477)
  * Fix bug: AttributeError in common/tools.py if keyring is
    missing (#473)
  * Fix bug: remote rename of 'new_snapshot' folder sometimes
    isn't recognized locally; rename local now
    (https://answers.launchpad.net/questions/271792)
  * Move source code and bug tracking to GitHub
* Tue Oct 20 2015 ronisbr@gmail.com
- Backport the upstream patch to fix the issue #473.
  * The patch backintime-fix-crash-run-user.patch is not
    necessary anymore and then it was removed.
* Mon Oct 19 2015 ronisbr@gmail.com
- Add a patch to temporarily fix a bug in which backintime crashes
  if it is executed as user. For more information, see:
    https://github.com/bit-team/backintime/issues/473
* Mon Oct 19 2015 ronisbr@gmail.com
- Clean spec file.
- Version bump to 1.1.8.
  Upstream changelog:
  * Fix bug: unlock private SSH key run into 5sec timeout if
    password is empty
  * show current app name and profile ID in syslog
    (https://launchpad.net/bugs/906213)
  * Fix bug: BiT freeze when activate 'Decode path' in 'Snapshot
    Log View'
  * Show 'Profiles' dropdown only in 'Last Log Viewer', add
    'Snapshots' dropdown in 'Snapshot Log Viewer'
    (https://launchpad.net/bugs/1478219)
  * Fix bug: empty grey window appears when starting the gui as
    root (https://launchpad.net/bugs/1493020)
  * do not restore permission if they are identical with current
    permissions
  * Fix bug: gnu_find_suffix_support doesn't set back to True
    (https://launchpad.net/bugs/1487781)
  * security issue: do not run user-callback in a shell
  * add option to not log user-callback output
  * Fix lintian warning dbus-policy-without-send-destination
  * apply timestamps-in-gzip.patch from Debian
    backintime/1.1.6-1 package
  * run multiple smart-remove jobs in one screen session
    (https://launchpad.net/bugs/1487781)
  * add error messages if PID file creation fail
  * Fix bug: dbus exception if dbus systembus is not running
  * Fix bug: depend on virtual package cron-daemon instead of
    cron for compatiblity with other cron implementations
    (https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=776856)
  * Fix bug: wasn't able to start from alternate install dir
    (https://launchpad.net/bugs/478689)
  * Fix bug: wasn't able to start from source dir
  * Add Warning about unsupported filesystems
  * use native Python code to check mountpoint
  * Add expert option for stdout and stderr redirection in
    cronjobs (https://answers.launchpad.net/questions/270105)
  * Fix bug: 'Inhibit Suspend' fails with
    'org.freedesktop.PowerManagement.Inhibit'
    (https://launchpad.net/bugs/1485242)
  * Fix bug: No mounting while selecting a secondary profile in
    the gui (https://launchpad.net/bugs/1481267)
  * remove shebang in common/askpass.py and
    common/create-manpage-backintime-config.py
  * Fix bug: fix for bug #1419466 broke crontab on Slackware
    (https://launchpad.net/bugs/1478576)
  * Fix bug: fix for bug #1431305 broke pw-cache on Ubuntu
    (https://launchpad.net/bugs/1431305)
  * Fix bash-complete
  * show 'man backintime' on Help; remove link to
    backintime.le-web.org (https://launchpad.net/bugs/1475995)
  * add --debug argument
  * Fix bug: Settings accepted empty strings for
    Host/User/Profile-ID (https://launchpad.net/bugs/1477733)
  * Fix bug: IndexError on 'check_remote_commands' due to too
    long args (https://launchpad.net/bugs/1471930)
  * add --local-backup, --no-local-backup and --delete option to
    restore on command-line (https://launchpad.net/bugs/1467239)
  * add 'backup on restore' option to confirm dialog
  * add check-config command for command-line
  * rewrite command-line argument parsing. Now using argparse
  * add expert option SSH command prefix
  * Fix bug: Makefile has no uninstall target
    (https://launchpad.net/bugs/1469152)
* Wed Sep 16 2015 ronisbr@gmail.com
-  Version bump to 1.1 branch (1.1.6), based on home:ecsos:Backup/backintime.
  * The 1.1 branch introduced a new QT4 GUI that replaced the
    old KDE and GNOME GUI. Therefore, the pacakges backintime-gnome and
    backintime-kde were replaced by the package backintime-qt4. Thus, both
    backintime and backintime-qt4 do not depend on any GNOME or KDE packages
    anymore.
  * The package now depends on python3 instead of python.
  * The patch `backintime-ssh-agent_only_if_password.patch` was
    updated to replace TABs with SPACEs for code indentation following the
    convention of `common/sshtools.py`.
- Upstream changelog from version 1.0.38 to version 1.1.6.
    Version 1.1.6
  * show Profile name in systrayicon menu
  * Fix bug: encrypted remote backup hangs on 'start
    encfsctl encode process'
    (https://launchpad.net/bugs/1455925)
  * make own Exceptions a childclass from
    BackInTimeException
  * Fix bug: Segmentation fault caused by two QApplication
  * Fix bug: no Changes [C] log entries with 'Check for
  * Fix bug: some changed options from Settingsdialog where
  * Fix bug: python version check fails on python 3.3
  * Specifying the SSH private key whenever ssh is called
  * add to in-/exclude directly from mainwindow
  * Fix bug: pw-cache didn't start on Mint KDE because of missing stdout
  * add option to run Smart Remove in background on remote host
  * Fix bug: failed to restore file names with white spaces using CLI
  * Fix bug: UnboundLocalError with 'last_snapshot' in _free_space
    (https://launchpad.net/bugs/1437623)
    Version 1.1.4
  * add option to keep new snapshot with 'full rsync mode' regardless of
    changes (https://launchpad.net/bugs/1434722)
  * Fix bug: wrong quote in 'Save config file'
  * Fix bug: Deleting the last snapshot does not update the last_snapshot
    symlink (https://launchpad.net/bugs/1434724)
  * remove base64 encoding for passwords as it doesn't add any security
    but broke the password process (https://launchpad.net/bugs/1431305)
  * add confirm dialog before restoring
    (https://launchpad.net/bugs/438079)
  * Fix bug: Wrong status text in the tray icon
    (https://launchpad.net/bugs/1429400)
  * add option to run only one snapshot at a time
  * Fix bug: restore permissions of lots of files made BackInTime
    unresposive (https://launchpad.net/bugs/1428423)
  * Fix bug: failed to restore file owner and group
  * cache uuid in config so it doesn't fail if the device isn't pluged in
    (https://launchpad.net/bugs/1426881)
  * add warning about wrong Python version in configure
  * prevent snapshots from being removed with restore and delete; show
    warning if restore and delete filesystem root
    (https://answers.launchpad.net/questions/262837)
  * Fix bug: OSError in free_space; add alternate method to get free space
  * add bash-completion
  * Fix bug: ugly theme while running as root on Gnome based DEs
    (https://launchpad.net/bugs/1418447)
  * Fix bug: filename with broken charset throwed UnicodeError exception
    (https://launchpad.net/bugs/1419694)
  * use 'crontab' instead of 'crontab -' to read from stdin
    (https://launchpad.net/bugs/1419466)
    Version 1.1.2
  * sort 'Backup folders' in main window
  * save in- and exclude sort order
  * use PolicyKit to install Udev rules
  * move compression from install to build in Makefiles
  * use pkexec to start backintime-qt4 as root
    Version 1.1.0
  * add tooltips for rsync options
  * make only one debian/control
  * multiselect files to restore (https://launchpad.net/bugs/1135886)
  * force run manual snapshots on battery
    (https://launchpad.net/bugs/861553)
  * backup encfs config to local config folder
  * apply 'install-docs-move.patch' from Debian package by Jonathan
    Wiltshire
  * add restore option to delete new files during restore
    (https://launchpad.net/bugs/1371951)
  * use flock to prevent two instances running at the same time
  * restore config dialog added (https://launchpad.net/bugs/480391)
  * inhibit suspend/hibernate while take_snapshot or restore
  * use more reliable code for get_user
  * implement anacrons functions inside BIT => more flexible schedules and
    no new timestamp if there was an error
  * automatically run in background if started with
    'backintime --backup-job'
  * fix typos and style warnings in manpages reported by Lintian
    (https://lintian.debian.org/full/jmw@debian.org.html#backintime_1.0.34-0.1)
  * add exclude files by size (https://launchpad.net/bugs/823719)
  * remove 'Auto Host/User/Profile-ID' as this is more confiusing than
    helping
  * Fix bug: check procname of pid-locks
    (https://launchpad.net/bugs/1341414)
  * optional run 'rsync' with 'nocache'
    (https://launchpad.net/bugs/1344528)
  * mark invalid exclude pattern with mode ssh-encrypted
  * make Settingsdialog tabs scrollable
  * remove colon (:) restriction in exclude pattern
  * prevent starting new snapshot if restore is running
  * Fix bug: Port check failed on IPv6
    (https://launchpad.net/bugs/1361634)
  * add top-level directory for tarball
    (https://launchpad.net/bugs/1359076)
  * add more user-callback events (on App start and exit, on mount and
    unmount)
  * add context menu to files view
  * remove snapshots from commandline
  * multi selection in timeline => remove multiple snapshots with one
    click
  * print warning if started with sudo
  * add more default exclude; remove [Cc]ache* from exclude
  * Fix bug: 'inotify_add_watch failed' while closing BIT
  * add option for custom rsync-options
  * add ProgressBar for rsync
  * add progress for smart-remove
  * remove old status-bar message after a snapshot crashed.
  * ask to include symlinks target instead link
    (https://launchpad.net/bugs/1117709)
  * port to Python 3.x
  * returncode >0 if there was an error
    (https://launchpad.net/bugs/1040995)
  * Enable user-callback script to cancel a backup by returning a non-zero
    exit code.
  * merge backintime-notify into backintime-qt4
  * add --gksu/--gksudo arg to qt4/configure
  * remember last path for each profile
    (https://bugs.launchpad.net/bugs/1254870)
  * sort include and exclude list
    (https://bugs.launchpad.net/bugs/1193149)
  * Timeline show tooltip 'Last check'
  * Fix bug: systray icon didn't show up
    (https://bugs.launchpad.net/backintime/+bug/658424)
  * show hidden files in FileDialog
    (https://bugs.launchpad.net/backintime/+bug/995925)
  * add button text for all buttons
    (https://bugs.launchpad.net/backintime/+bug/992020)
  * add shortcuts (https://bugs.launchpad.net/backintime/+bug/686694)
  * add menubar (https://bugs.launchpad.net/backintime/+bug/528851)
  * port KDE4 GUI to pure Qt4 to replace both KDE4 and Gnome GUI
    Version 1.0.40
  * use fingerprint to check if ssh key was unlocked correctly
    (https://answers.launchpad.net/questions/256408)
  * add fallback method to get UUID
    (https://answers.launchpad.net/questions/254140)
  * Fix bug: 'Attempt to unlock mutex that was not locked'... this time
    for good
* Thu Oct 16 2014 hrvoje.senjan@gmail.com
- Update Source URL
* Sun Oct 12 2014 ecsos@schirra.net
- update to 1.0.38
  * Fix bug: 'Attempt to unlock mutex that was not locked' in
    gnomeplugin (https://answers.launchpad.net/questions/255225)
  * compare os.path.realpath instead of os.stat to get devices UUID
  * Fix bug: housekeeping by gnome-session-daemon might delete
    backup and original data
    (https://bugs.launchpad.net/bugs/1374343)
  * Fix bug: Type Error in 'backintime --decode'
    (https://bugs.launchpad.net/bugs/1365072)
  * Fix bug: take_snapshot didn't wait for snapshot folder come
    available if notifications are disabled
    (https://bugs.launchpad.net/bugs/1332979)
- update from 1.0.34
  * remove UbuntuOne from exclude
    (https://bugs.launchpad.net/bugs/1340131)
  * Gray out 'Add Profile' if 'Main Profile' isn't configured yet
    (https://bugs.launchpad.net/bugs/1335545)
  * Don't check for fuse group-membership if group doesn't exist
  * Fix bug: backintime-kde4 as root failed to load ssh-key
    (https://bugs.launchpad.net/bugs/1276348)
  * Fix bug: kdesystrayicon.py crashes because of missing environ
    (https://bugs.launchpad.net/bugs/1332126)
  * Fix bug: OSError if sshfs/encfs is not installed
    (https://bugs.launchpad.net/bugs/1316288)
  * Fix bug: TypeError in config.py check_config()
    (https://bugzilla.redhat.com/show_bug.cgi?id=1091644)
  * Fix bug: unhandled exception in create_last_snapshot_symlink()
    (https://bugs.launchpad.net/bugs/1269991)
  * disable keyring for root
* Mon Jan 20 2014 kdupke@suse.com
- added backintime-ssh-agent_only_if_password.patch, does not connect
  ssh-agent if password isn't set. Allow passwordless ssh-key as root.
* Thu Jan  2 2014 ecsos@schirra.net
- Update to upstream version 1.0.34
  * sync/flush all disks before shutdown (https://bugs.launchpad.net/bugs/1261031)
  * Fix bug: BIT running as root shutdown after snapshot, regardless of option checked (https://bugs.launchpad.net/bugs/1261022)
- Update to upstream version 1.0.32
  * Fix bug: cron scheduled snapshots won't start with 1.0.30
- Update to upstream version 1.0.30
  * scheduled and manual snapshots use --config
  * make configure scripts portable (https://bugs.launchpad.net/backintime/+bug/377429)
  * Fix bug: udev rule doesn't finish (https://bugs.launchpad.net/backintime/+bug/1249466)
  * add symlink last_snapshot (https://bugs.launchpad.net/backintime/+bug/787118)
  * add virtual package backintime-kde for PPA
  * Fix multiple errors in PPA build process; reorganise updateversion.sh
  * Fix bug: Mate and xfce desktop didn't show systray icon (https://bugs.launchpad.net/backintime/+bug/658424/comments/31)
  * add option to run rsync with 'nice' or 'ionice' on remote host (https://bugs.launchpad.net/backintime/+bug/1240301)
  * add Shutdown button to shutdown system after snapshot has finished (https://bugs.launchpad.net/backintime/+bug/838742)
  * Fix bug: Ubuntu Lucid dosn't provide SecretServiceKeyring (https://bugs.launchpad.net/backintime/+bug/1243911)
  * wrap long lines for syslog
  * Fix bug: 'gksu backintime-gnome' failed with dbus.exceptions.DBusException
* Wed Nov 13 2013 toddrme2178@gmail.com
- Update to upstream version 1.0.28
  * remove config on 'apt-get purge'
  * add more options for configure scripts; update README
  * add udev schedule (run BIT as soon as the drive is connected)
  * Fix bug: AttributeError with python-keyring>1.6.1 [#1234024](https://bugs.launchpad.net/backintime/+bug/1234024)
  * Fix bug: TypeError: KDirModel.removeColumns() is a private method in kde4/app.py [#1232694](https://bugs.launchpad.net/backintime/+bug/1232694)
  * add '--checksum' commandline option [#886021](https://bugs.launchpad.net/backintime/+bug/886021)
  * Fix bug: sshfs mount disconnect after a while due to some firewalls (add ServerAliveInterval) [#235685](https://answers.launchpad.net/backintime/+question/235685)
  * Fix bug: Ping fails if ICMP is disabled on remote host [#1226718](https://bugs.launchpad.net/backintime/+bug/1226718)
  * Fix bug: KeyError in getgrnam if there is no 'fuse' group [#1225561](https://bugs.launchpad.net/backintime/+bug/1225561)
  * Fix bug: anacrontab won't work with profilename with spaces [#1224620](https://bugs.launchpad.net/backintime/+bug/1224620)
  * Fix bug: NameError in tools.move_snapshots_folder [#871466](https://bugs.launchpad.net/backintime/+bug/871466)
  * Fix bug: KPassivePopup is not defined [#871475](https://bugs.launchpad.net/backintime/+bug/871475)
  * multi selection for include and exclude list [#660753](https://bugs.launchpad.net/backintime/+bug/660753)
  * Fix bug: ValueError while reading pw-cache PID [#235407](https://answers.launchpad.net/backintime/+question/235407)
- Update to upstream version 1.0.26
  * add feature: keep min free inodes
  * roll back commit 836.1.5 (check free-space on ssh remote host): statvfs DOES work over sshfs. But not with quite outdated sshd
  * add daily anacron schedule
  * add delete button and 'list only equal' in Snapshot dialog; multiSelect in snapshot list
  * add manpage backintime-config and config-examples
  * Fix bug: Restore makes files public during the operation
  * Fix bug: Cannot keep modifications to cron (https://bugs.launchpad.net/backintime/+bug/698106)
  * add feature: restore from command line; add option --config
  * Fix bug: cannot stat 'backintime-kde4-root.desktop.kdesudo' (https://bugs.launchpad.net/backintime/+bug/696659)
  * Fix bug: unreadable dark KDE color schemes (https://bugs.launchpad.net/backintime/+bug/1184920)
  * use 'ps ax' to check if 'backintime --pw-cache' is still running
  * mount after locking, unmount before unlocking in take_snapshot
  * Fix bug: permission denied if remote uid wasn't the same as local uid
  * add option --bwlimit for rsync
  * redirect logger.error and .warning to stderr; new argument --quiet
  * deactivate 'Save Password' if no keyring is available
  * use Password-cache for user-input too
  * handle two Passwords
  * add 'SSH encrypted': mount / with encfs reverse and sync encrypted with rsync. EXPERIMENTEL!
  * add 'Local encrypted': mount encfs
- Update to upstream version 1.0.24
  * hide check_for_canges if full_rsync_mode is checked
  * DEFAULT_EXCLUDE system folders with /foo/* so at least the folder itself will backup
  * DEFAULT_EXCLUDE /run; exclude MOUNT_ROOT with higher priority and not with DEFAULT_EXCLUDE anymore
  * Fix bug: 'CalledProcessError' object has no attribute 'strerror'
  * Fix bug: quote rsync remote path with spaces
  * 'Save Password' default off to avoid problems with existing profiles
  * if restore uid/gid failed try to restore at least gid
  * SSH need to store permissions in seperate file with "Full rsync mode" because remote user might not be able to store ownership
  * Fix bug: restore permission failed on "Full rsync mode"
  * Fix bug: glib.GError: Unknown internal child: selection
  * Fix bug: GtkWarning: Unknown property: GtkLabel.margin-top
  * Fix bug: check keyring backend only if password is needed
  * switch to 'find -exec cmd {} +' (https://bugs.launchpad.net/backintime/+bug/1157639)
  * change all indent tabs to 4 spaces
- Update to upstream version 1.0.22
  * check free-space on ssh remote host (statvfs didn't work over sshfs)
  * Add Password storage mode ssh
  * Add "Full rsync mode" (can be faster but ...)
  * Fix bug: "Restore to..." failed due to spaces in directory name (https://bugs.launchpad.net/backintime/+bug/1096319)
  * Fix bug: host not found in known_hosts if port != 22 (https://bugs.launchpad.net/backintime/+bug/1130356)
  * Fix bug: sshtools.py used not POSIX conform conditionals
- Update requires and buildrequires.
- Remove upstreamed omit_KDirModel.removeColumns.patch
- Split doc and lang packages
* Thu Oct 17 2013 hrvoje.senjan@gmail.com
- Added omit_KDirModel.removeColumns.patch, fixes crash of kde
  frontend (bnc#846526)
* Mon Dec 17 2012 tejas.guruswamy@opensuse.org
- Update to upstream version 1.0.20
  * Fix bug: restore remote path with spaces using mode ssh returned error
  * Fix packages: man & translations
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/1077446
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/1078979
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/1079479
  * Map multiple arguments for gettext so they can be rearranged by translators
  * Add links to: website, documentation, report a bug, answers, faq
  * Use libnotify for gnome/kde4 notifications instead of gnome specific libraries
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/1059247
  * Add more schedule options: every 30 min, every 2 hours, every 4 hours, every 6 hours & every 12 hours
  * Add generic mount-framework
  * Add mode 'SSH' for backups on remote host using ssh protocol.
  * Fix bug: wrong path if restore system root
  * Fix bug: glade (xml) files did not translate
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/1073867
  * Add "Restore to ..." in replacement of copy (with or without drag & drop) because copy don't restore user/group/rights
* Tue Oct 16 2012 coolo@suse.com
- fix file list
* Wed Feb  1 2012 tejas.guruswamy@opensuse.org
- Fix duplicated omf files
* Wed Jul 20 2011 tejas.guruswamy@opensuse.org
- new upstream version 1.0.8
  * Fix bug: lp#723545
    + Cache UID/GID to improve backup speed
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/705237
    + wrong profile name in message box
  * Fix bug: lp#696663
    + Empty directories created during build
  * Fix bug: lp#671946
    + Invalid notification ID
* Sun Jun 26 2011 tejas.guruswamy@opensuse.org
- Fix missing language directories
* Mon Apr 18 2011 tejas.guruswamy@opensuse.org
- Imported package from packman
* Mon Jan  3 2011 detlef@links2linux.de
- new upstream version <1.0.6>
  * Fix bug:
    https://bugs.launchpad.net/backintime/+bug/676223
    https://bugs.launchpad.net/backintime/+bug/672705
  * Smart remove: configurable options:
    https://bugs.launchpad.net/backintime/+bug/406765
* Sat Oct 30 2010 detlef@links2linux.de
- new upstream version <1.0.4>
  * SettingsDialog: show highly recommended excludes
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/664783
  * Option to use checksum to detect changes (https://bugs.launchpad.net/backintime/+bug/666964)
  * Option to select log verbosity (https://bugs.launchpad.net/backintime/+bug/664423)
  * Gnome: use gloobus-preview if installed
* Sat Oct 16 2010 detlef@links2linux.de
- new upstream version <1.0.2>
  * reduce log file (no more duplicate "Compare with..." lines)
  * declare backintime-kde4 packages as a replacement of backintime-kde
* Wed Sep 15 2010 detlef@links2linux.de
- new upstream version <1.0>
  * add '.dropbox*' to default exclude patterns (https://bugs.launchpad.net/backintime/+bug/628172)
  * add option to take a snapshot at every boot (https://bugs.launchpad.net/backintime/+bug/621810)
  * add continue on errors (https://bugs.launchpad.net/backintime/+bug/616299)
  * add expert options: copy unsafe links & copy links
  * "user-callback" replace "user.callback" and receive profile informations
  * documentation: on-line only (easier to maintain)
  * add error log and error log view dialog (Gnome & KDE4)
  * merge with: lp:~dave2010/backintime/minor-edits
  * merge with: lp:~mcfonty/backintime/unique-snapshots-view
  * reduce memory usage during compare with previous snapshot process
  * custom backup hour (for daily backups or mode): https://bugs.launchpad.net/backintime/+bug/507451
  * smart remove was slightly changed (https://bugs.launchpad.net/backintime/+bug/502435)
  * make backup on restore optional
  * add ionice support for user/cron backup process
  * remove "schedule per included directory" (profiles do that) (+ bug LP: #412470)
  * update Slovak translation (Tomáš Vadina <kyberdev@gmail.com>)
  * multiple profiles support
  * backintime snapshot folder is restructured to ../backintime/machine/user/profile_id/
  * added the possibility to include other snapshot folders within a profile, it can only read those, there is not a GUI implementation yet
  * added a tag suffix to the snapshot_id, to avoid double snapshot_ids
  * added a desktop file for kdesu and a test if kdesu or kdesudo should be used (LP: #389988)
  * added expert option to disable snapshots when on battery (LP: #388178)
  * snapshots are stored entirely read-only (LP: #386275)
  * changed default exclude patterns to caches, thumbnails, trashbins, and backups (LP: #422132)
  * write access to snapshot folder is checked & change to snapshot version 2 (LP: #423086)
  * Used a more standard crontab syntax (LP: #409783)
  * Stop the "Over zealous removal of crontab entries" (LP: #451811)
  * and many bugfixes
* Sat Aug 22 2009 detlef@links2linux.de
- fix Requires
* Mon Jun 22 2009 herbert@links2linux.de
- new upstream version <0.9.26>
  * update translations from Launchpad
  * Fix a but smart-remove algorithm (https://bugs.launchpad.net/backintime/+bug/376104)
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/374477
  * Fix bug: https://bugs.launchpad.net/backintime/+bug/375113
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * add '--no-check' option to configure scripts
  * use only 'folder' term (more consistent with GNOME/KDE)
  * add 'expert option': enable/disable nice for cron jobs
  * GNOME & KDE4: refresh snapshots button force files view to update too
  * you can include a backup parent directory (backup directory will auto-exclude itself)
  * fix some small bugs
- new upstream version <0.9.24>
  * update translations
  * KDE4: fix python string <=> QString problems
  * KDE4 FilesView/SnapshotsDialog: ctrl-click just select (don't execute)
  * KDE4: fix crush after "take snapshot" process (https://bugs.launchpad.net/backintime/+bug/366241)
  * store basic permission in a special file so it can restore them correctly (event from NTFS)
  * add config version
  * implement Gnome/KDE4 systray icons and user.callback as plugins
  * reorganize code: common/GNOME/KDE4
  * GNOME: break the big glade file in multiple file
  * backintime is no longer aware of 'backintime-gnome' and 'backintime-kde4'
    (you need run 'backintime-gnome' for GNOME version and 'backintime-kde4' for KDE4 version)
- new upstream version <0.9.22.1>
  * fix French translation
- new upstream version <0.9.22>
  * update translations from Launchpad
  * KDE4: fix some translation problems
  * remove --safe-links for save/restore (this means copy symlinks as symlinks)
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * create directory now use python os.makedirs (replace use of mkdir command)
  * KDE4: fix a crush related to QString - python string conversion
  * GNOME & KDE4 SettingsDialog: if schedule automatic backups per directory is set, global schedule is hidden
  * GNOME FilesView: thread "*~" files (backup files) as hidden files
  * GNOME: use gtk-preferences icon for SettingsDialog (replace gtk-execute icon)
  * expert option: $XDG_CONFIG_HOME/backintime/user.callback (if exists) is called a different steps
    of a "take snapshot" process (before, after, on error, is a new snapshot was taken).
  * add more command line options: --snapshots-list, --snapshots-list-path, --last-snapshot, --last-snapshot-path
  * follow FreeDesktop directories specs:
    $XDG_DATA_HOME (default: $HOME/.local/share) to store app.lock files
    $XDG_CONFIG_HOME (default: $HOME/.config) to save settings
  * new install system: use more common steps (./configure; make; sudo make install)
- new upstream version <0.9.20>
  * smart remove: fix an important bug and make it more verbose in syslog
  * update Spanish translation (Francisco Manuel García Claramonte <franciscomanuel.garcia@hispalinux.es>)
- new upstream version <0.9.18>
  * update translations from Launchpad
  * update Slovak translation (Tomáš Vadina <kyberdev@gmail.com>)
  * update French translation (Michel Corps <mahikeulbody@gmail.com>)
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * GNOME bugfix: fix a crush in files view for files with special characters (ex: "a%%%%20b")
  * GNOME SettingsDialog bugfix: if snapshots path is a new created folder, snapshots navigation (files view) don't work
  * update doc
  * GNOME & KDE4 MainWindow: Rename "Places" list with "Snapshots"
  * GNOME SettingsDialog bugfix: modify something, then press cancel. If you reopen the dialog it show wrong values (the ones before cancel)
  * GNOME & KDE4: add root mode menu entries (use gksu for gnome and kdesudo for kde)
  * GNOME & KDE4: MainWindow - Files view: if the current directory don't exists in current snapshot display a message
  * SettingDialog: add an expert option to enable to schedule automatic backups per directory
  * SettingDialog: schedule automatic backups - if the application can't find crontab it show an error
  * SettingDialog: if the application can't write in snapshots directory there should be an error message
  * add Polish translation (Paweł Hołuj <pholuj@gmail.com>)
  * add cron in common package dependencies
  * GNOME & KDE4: rework settings dialog
  * SettingDialog: add an option to enable/disable notifications
* Fri Apr 24 2009 herbert@links2linux.de
- require python-kde4 for kde subpackage
* Tue Mar 17 2009 detlef@links2linux.de
- new upstream version <0.9.16.1>
  * fix a bug/crush for French version
  * update translations
  * don’t show the snapshot that is being taken in snapshots list
  * GNOME & KDE4: when the application starts and snapshots directory don’t exists show a messagebox
  * give more information for ‘take snapshot’ progress (to prove that is not blocked)
  * MainWindow: rename ‘Timeline’ column with ‘Snapshots’
  * when it tries to take a snapshot if the snapshots directory don’t exists  (it is on a removable drive that is not plugged) it will notify and wait maxmimum 30  seconds (for the drive to be plugged)
  * GNOME & KDE4: add notify if the snapshots directory don’t exists
  * KDE4: rework MainWindow
* Thu Mar 12 2009 detlef@links2linux.de
- fix DOCDIR in config.py
* Thu Mar  5 2009 detlef@links2linux.de
- new upstream version <0.9.14>
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * update Swedish translation (Niklas Grahn <terra.unknown@yahoo.com>)
  * update Spanish translation (Francisco Manuel García Claramonte <franciscomanuel.garcia@hispalinux.es>)
  * update French translation (Michel Corps <mahikeulbody@gmail.com>)
  * GNOME & KDE4: rework MainWindow
  * GNOME & KDE4: rework SettingsDialog
  * GNOME & KDE4: add "smart" remove
* Sat Feb 28 2009 detlef@links2linux.de
- new upstream version <0.9.12>
  * bug fix: now if you include “.abc” folder and exclude “.*”, “.abc” will be saved in the snapshot
  * KDE4: add help
  * add Slovenian translation
  * bug fix (GNOME): bookmarks with special characters
  * add Swedish translation
  * KDE4: drop and drop from backintime files view to any file manager
  * bug fix: fix a segfault when running from cron
* Sat Feb 21 2009 detlef@links2linux.de
- new upstream version <0.9.8>
  * update Spanish translation
  * bug fix: unable to restore files that contains space char in their name
  * unsafe links are ignored (that means that a link to a file/directory outside of include directories are ignored)
  * KDE4: add copy to clipboard
  * KDE4: sort files by name, size or date
  * cron 5/10 minutes: replace mutiple lines with a single crontab line using divide (*/5 or */10)
  * cron: when called from cron redirect output (stdout & stderr) to /dev/null
* Tue Feb 10 2009 detlef@links2linux.de
- new upstream version <0.9.6>
- split package in backintime, backintime-gnome and backintime-kde4
  * update Spanish translation
  * update German translation
  * GNOME: update docbook
  * KDE4: add snapshots dialog
  * GNOME & KDE4: add update snapshots button
  * GNOME: handle special folders icons (home, desktop)
* Sat Jan 31 2009 detlef@links2linux.de
- new upstream version <0.9.4>
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * gnome: better handling of 'take snapshot' status icon
  * kde4 (>= 4.1): first version (not finished)
  * update man
* Fri Jan 16 2009 detlef@links2linux.de
- new upstream version <0.9.2>
  * update Spanish translation (Francisco Manuel García Claramonte <franciscomanuel.garcia@hispalinux.es>)
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * bug fix: if you add "/a" in include directories and "/a/b" in exclude patterns, "/a/b*" items
    are not excluded
  * replace diff with rsync to check if a new snapshot is needed
  * code cleanup
  * add show hidden & backup files toggle button for files view
  * bug fix: it does not include ".*" items even if they are not excluded
    (the items was included but not showed because hidden & backup files was never displayed
    in files view in previous versions)
* Sun Jan 11 2009 detlef@links2linux.de
- new upstream version <0.9>
  * update Spanish translation (Francisco Manuel García Claramonte <franciscomanuel.garcia@hispalinux.es>)
  * make deb packages more debian friendly (thanks to Michael Wiedmann <mw@miwie.in-berlin.de>)
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * bug fix: when you open snapshots dialog for the second time ( or more ) and you make a diff.
    it will make the diff on the file for the first dialog ( all previous dialogs ) and then for.
    the current one
  * better separation between common and gnome specific files and.
    divide backintime package in backintime-common & backintime-gnome
    ( this will allow me to write other GUI frontends like KDE4 or KDE )
  * code cleanup
* Sun Dec 21 2008 detlef@links2linux.de
- new upstream version <0.8.20>
  * bug fix: sorting files/directories by name is now case insensitive
  * getmessages.sh: ignore "gtk-" items (this are gtk stock item ids and sould not be changed)
* Wed Dec 17 2008 detlef@links2linux.de
- new upstream version <0.8.18>
  * update man/docbook
  * add sort columns in MainWindow:FileView and SnapshotsDialog
  * fix German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
* Fri Dec 12 2008 detlef@links2linux.de
- new upstream version <0.8.16>
  * add Drag & Drop from MainWindow:FileView/SnapshotsDialog to Nautilus
  * update German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
* Mon Dec  8 2008 detlef@links2linux.de
- new upstream version <0.8.14>
  * add more command line parameters ( --version, --snapshots, --help )
  * fix a crush for getting info on dead symbolic links
  * when taking a new backup based on the previous one don't copy the previous extra info (ex: name)
  * copy unsafe links when taking a snapshot
* Sat Dec  6 2008 detlef@links2linux.de
- new upstream version <0.8.12>
  * add German translation (Michael Wiedmann <mw@miwie.in-berlin.de>)
  * add SnapshotNameDialog
  * add Name/Remove snapshot in main toolbar
  * change the way it detects if the mainwindow is the ative window (no dialogs)
  * Toolbars: show icons only
  * update Spanish translation (Francisco Manuel García Claramonte <franciscomanuel.garcia@hispalinux.es>)
* Sat Nov 22 2008 detlef@links2linux.de
- Initial build.
